/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of Smetana.
 * Smetana is a partial translation of Graphviz/Dot sources from C to Java.
 *
 * (C) Copyright 2009-2017, Arnaud Roques
 *
 * This translation is distributed under the same Licence as the original C program:
 * 
 *************************************************************************
 * Copyright (c) 2011 AT&T Intellectual Property 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors: See CVS logs. Details at http://www.graphviz.org/
 *************************************************************************
 *
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS ECLIPSE PUBLIC
 * LICENSE ("AGREEMENT"). [Eclipse Public License - v 1.0]
 * 
 * ANY USE, REPRODUCTION OR DISTRIBUTION OF THE PROGRAM CONSTITUTES
 * RECIPIENT'S ACCEPTANCE OF THIS AGREEMENT.
 * 
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package gen.lib.label;
import static gen.lib.cdt.dtopen__c.dtopen;
import static gen.lib.common.memory__c.zmalloc;
import static gen.lib.label.index__c.RTreeOpen;
import static smetana.core.JUtils.sizeof;
import static smetana.core.Macro.N;
import static smetana.core.Macro.UNSUPPORTED;
import h.BestPos_t;
import h.XLabels_t;
import h._dt_s;
import h._dtdisc_s;
import h.label_params_t;
import smetana.core.Z;
import smetana.core.__ptr__;

public class xlabels__c {
//1 9k44uhd5foylaeoekf3llonjq
// extern Dtmethod_t* 	Dtset


//1 1ahfywsmzcpcig2oxm7pt9ihj
// extern Dtmethod_t* 	Dtbag


//1 anhghfj3k7dmkudy2n7rvt31v
// extern Dtmethod_t* 	Dtoset


//1 5l6oj1ux946zjwvir94ykejbc
// extern Dtmethod_t* 	Dtobag


//1 2wtf222ak6cui8cfjnw6w377z
// extern Dtmethod_t*	Dtlist


//1 d1s1s6ibtcsmst88e3057u9r7
// extern Dtmethod_t*	Dtstack


//1 axa7mflo824p6fspjn1rdk0mt
// extern Dtmethod_t*	Dtqueue


//1 ega812utobm4xx9oa9w9ayij6
// extern Dtmethod_t*	Dtdeque


//1 cyfr996ur43045jv1tjbelzmj
// extern Dtmethod_t*	Dtorder


//1 wlofoiftbjgrrabzb2brkycg
// extern Dtmethod_t*	Dttree


//1 12bds94t7voj7ulwpcvgf6agr
// extern Dtmethod_t*	Dthash


//1 9lqknzty480cy7zsubmabkk8h
// extern Dtmethod_t	_Dttree


//1 bvn6zkbcp8vjdhkccqo1xrkrb
// extern Dtmethod_t	_Dthash


//1 9lidhtd6nsmmv3e7vjv9e10gw
// extern Dtmethod_t	_Dtlist


//1 34ujfamjxo7xn89u90oh2k6f8
// extern Dtmethod_t	_Dtqueue


//1 3jy4aceckzkdv950h89p4wjc8
// extern Dtmethod_t	_Dtstack


//1 1lrfssuxf2e1e5pvk6j7qrff6
// extern int Verbose


//1 17dmpzc4uhvmrcx0x00aw2gbc
// Dtdisc_t Hdisc = 




//3 5p3ac8qk4gnne5hj1dc21ysi
// static int icompare(Dt_t * dt, void * v1, void * v2, Dtdisc_t * disc) 
public static int icompare(_dt_s dt, __ptr__ v1, __ptr__ v2, _dtdisc_s disc) {
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("ehks25fxahyjbjd4lm6ryh9su"); //     int k1 = *((int *) v1), k2 = *((int *) v2);
UNSUPPORTED("6in30ubiocmaih693f0arymgc"); //     return k1 - k2;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 88mbfm305igsr7cew5qx6yldp
// static XLabels_t *xlnew(object_t * objs, int n_objs, 			xlabel_t * lbls, int n_lbls, 			label_params_t * params) 
public static XLabels_t xlnew(__ptr__ objs, int n_objs, __ptr__ lbls, int n_lbls, label_params_t params) {
__ptr__ xlp;
xlp = zmalloc(sizeof(XLabels_t.class));
/* used to load the rtree in hilbert space filling curve order */
xlp.setPtr("hdx", dtopen(Z.z().Hdisc.amp(), Z.z().Dtobag));
if (N(xlp.getPtr("hdx"))) {
UNSUPPORTED("4t1y5iinm4310lkpvbal1spve"); // 	fprintf(stderr, "out of memory\n");
UNSUPPORTED("3m406diamp5s5kwcqtwo4pshf"); // 	goto bad;
}
/* for querying intersection candidates */
xlp.setPtr("spdx", RTreeOpen());
UNSUPPORTED("7elrkgy2129t2ut4mi03dhf75"); //     if (!(xlp->spdx = RTreeOpen())) {
UNSUPPORTED("4t1y5iinm4310lkpvbal1spve"); // 	fprintf(stderr, "out of memory\n");
UNSUPPORTED("3m406diamp5s5kwcqtwo4pshf"); // 	goto bad;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
/* save arg pointers in the handle */
UNSUPPORTED("ava6c0wrmq2d6j1i4j7bd1lpp"); //     xlp->objs = objs;
UNSUPPORTED("85sh2ov52z31nsy9mk5su9p5p"); //     xlp->n_objs = n_objs;
UNSUPPORTED("3et8g76wlkf60sgxrmi3z1vom"); //     xlp->lbls = lbls;
UNSUPPORTED("2pwe3sog0n7styjgekuhrnd5e"); //     xlp->n_lbls = n_lbls;
UNSUPPORTED("52j9u0n44sdpwexr3bunb46zi"); //     xlp->params = params;
UNSUPPORTED("64t9yhsoz02rjp8vy1as25a5n"); //     return xlp;
UNSUPPORTED("98zx7s9vt8t1s5x9l35evcxnz"); //   bad:
UNSUPPORTED("66s40csd2ivd8rx4h2ut8oai5"); //     if (xlp->hdx)
UNSUPPORTED("8mg8tqxa78f1nfk4jh9drw2n0"); // 	dtclose(xlp->hdx);
UNSUPPORTED("b9uy03exphaovgyz5t4gru409"); //     if (xlp->spdx)
UNSUPPORTED("4cfpl6hom6vo3btrjlhfmn6mi"); // 	RTreeClose(xlp->spdx);
UNSUPPORTED("dms04fhv1vao18v2p0lmk80xf"); //     free(xlp);
UNSUPPORTED("5oxhd3fvp0gfmrmz12vndnjt"); //     return 0;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 apvhod2s1yjb8717rb7gie2kb
// static void xlfree(XLabels_t * xlp) 
public static Object xlfree(Object... arg) {
UNSUPPORTED("7jv3t0oxe54lacl7qn1meznth"); // static void xlfree(XLabels_t * xlp)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("3120ftcrfb2pccpafsxzl14te"); //     RTreeClose(xlp->spdx);
UNSUPPORTED("dms04fhv1vao18v2p0lmk80xf"); //     free(xlp);
UNSUPPORTED("b9185t6i77ez1ac587ul8ndnc"); //     return;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 6lz36gkh8fla3z6f0lxniy368
// static int floorLog2(unsigned int n) 
public static Object floorLog2(Object... arg) {
UNSUPPORTED("dhjwlofpfy5gop5y81eemv6i4"); // static int floorLog2(unsigned int n)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("3xzujk207ipx0d60nbbrwyjez"); //     int pos = 0;
UNSUPPORTED("f0os7tzuki1s9mllsml3zu2fd"); //     if (n == 0)
UNSUPPORTED("8d9xfgejx5vgd6shva5wk5k06"); // 	return -1;
UNSUPPORTED("4b22up0qcghijti04gz41jqiz"); //     if (n >= 1 << 16) {
UNSUPPORTED("b8h1lnvuhauq15z5k0fs5u2l1"); // 	n >>= 16;
UNSUPPORTED("e1kd6x1c70e7l8ml3qgzahq34"); // 	pos += 16;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("a7hxj1hb2pc8py8ywsfit3q4n"); //     if (n >= 1 << 8) {
UNSUPPORTED("aioe8c94e5sluu8n00fdgq128"); // 	n >>= 8;
UNSUPPORTED("b5apnzow59vwb4z38m0bgaxuj"); // 	pos += 8;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("8ln2bn60t9zq7iigfqy9wa5dk"); //     if (n >= 1 << 4) {
UNSUPPORTED("albua8gefgieknhiuhr1cook"); // 	n >>= 4;
UNSUPPORTED("5ivee6b3gs2khi9h8mpbr20g9"); // 	pos += 4;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("930rjgw6ueudlb4emmrfw8y8w"); //     if (n >= 1 << 2) {
UNSUPPORTED("3p8vzi941bcva583xzhk2o7qb"); // 	n >>= 2;
UNSUPPORTED("3t90pfuwl7kz4zpjrsa99cof8"); // 	pos += 2;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("8b1fqmv1sxvuyxs3dcp7aas0k"); //     if (n >= 1 << 1) {
UNSUPPORTED("nx53w89cor5x9akadlbw5et8"); // 	pos += 1;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("2kr5zds5y6oiaubm8wiunqccr"); //     return pos;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 uvnzthcpf4xiih05gxie2rx1
// unsigned int xlhorder(XLabels_t * xlp) 
public static Object xlhorder(Object... arg) {
UNSUPPORTED("9rtsoeopc1glcmntqwf7hz6x7"); // unsigned int xlhorder(XLabels_t * xlp)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("7w1e4a6q9gftmlsxkc4v7eq9d"); //     double maxx = xlp->params->bb.UR.x, maxy = xlp->params->bb.UR.y;
UNSUPPORTED("147h47bz0sqql0238qat4fdky"); //     return floorLog2(maxx > maxy ? maxx : maxy) + 1;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 9lkyvq87bawe3yon7bdwvcjzq
// static unsigned int hd_hil_s_from_xy(point p, int n) 
public static Object hd_hil_s_from_xy(Object... arg) {
UNSUPPORTED("9zi37w33fe5wi8h5d2dymr0tt"); // static unsigned int hd_hil_s_from_xy(point p, int n)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("65resmfdu81d1xg2em5l84y82"); //     int i, x = p.x, y = p.y, xi, yi;
UNSUPPORTED("3s2drtfrrzifwhrt8rk6kq5gq"); //     unsigned s;
UNSUPPORTED("bd5j4s2m9y2fcgu9giqi9qrhy"); //     s = 0;			/* Initialize. */
UNSUPPORTED("9d7993w9kft7mplobqeb9boaz"); //     for (i = n - 1; i >= 0; i--) {
UNSUPPORTED("c1xqmgsdfzeebwk2yfoz65pue"); // 	xi = (x >> i) & 1;	/* Get bit i of x. */
UNSUPPORTED("270wzledmbxq3z8mp5tz7ezib"); // 	yi = (y >> i) & 1;	/* Get bit i of y. */
UNSUPPORTED("3d69e96cdg4apqijubufzse5z"); // 	s = 4 * s + 2 * xi + (xi ^ yi);	/* Append two bits to s. */
UNSUPPORTED("c4cig8vru225s8qy4aj21mfe0"); // 	x = x ^ y;		/* These 3 lines swap */
UNSUPPORTED("7r0w00av090u8a4vi14al4ct6"); // 	y = y ^ (x & (yi - 1));	/* x and y if yi = 0. */
UNSUPPORTED("cpz7xdfh4gvp5hufdb1ij5amy"); // 	x = x ^ y;
UNSUPPORTED("7i7jygllv89x29npu61cfn74p"); // 	x = x ^ (-xi & (yi - 1));	/* Complement x and y if */
UNSUPPORTED("5p8kbkyzcbsr9m1b1fl7z3q0h"); // 	y = y ^ (-xi & (yi - 1));	/* xi = 1 and yi = 0. */
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("3y6wj3ntgmr1qkdpm7wp1dsch"); //     return s;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 bpkzwylrchx5wta1qhytfgbtr
// static double aabbaabb(Rect_t * r, Rect_t * s) 
public static Object aabbaabb(Object... arg) {
UNSUPPORTED("21oyvapf2qfnxqid5aolv4mmr"); // static double aabbaabb(Rect_t * r, Rect_t * s)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("dywr73ggaui4ayztq3tmljs4z"); //     /* per dimension if( max < omin || min > omax) */
UNSUPPORTED("981pm44oz7wkhcspjabhjqpmq"); //     double iminx, iminy, imaxx, imaxy;
UNSUPPORTED("60uso6twsxyml3pff70yndkys"); //     if (r->boundary[2] < s->boundary[0] || r->boundary[0] > s->boundary[2])
UNSUPPORTED("c9ckhc8veujmwcw0ar3u3zld4"); // 	return 0;
UNSUPPORTED("1tavt6umo55xyoarc64k3dxs0"); //     if (r->boundary[3] < s->boundary[1] || r->boundary[1] > s->boundary[3])
UNSUPPORTED("c9ckhc8veujmwcw0ar3u3zld4"); // 	return 0;
UNSUPPORTED("ls92qicz53qcx6cwst6f8om3"); //     /* if we get here we have an intersection */
UNSUPPORTED("31cw8fo82001qx6nsg22hugnf"); //     /* rightmost left edge of the 2 rectangles */
UNSUPPORTED("7d66kym3m7c0ya8b4kt7vjtvv"); //     iminx =
UNSUPPORTED("2ohiqb8vdv4gbnzqigtqd47c3"); // 	r->boundary[0] > s->boundary[0] ? r->boundary[0] : s->boundary[0];
UNSUPPORTED("2bf3t8qfsxq7y4d98hc3p59gv"); //     /* upmost bottom edge */
UNSUPPORTED("cvk4ll2zvw3sljlm63j6bcjr8"); //     iminy =
UNSUPPORTED("13n8uz9c82r3pkg85oh43qf74"); // 	r->boundary[1] > s->boundary[1] ? r->boundary[1] : s->boundary[1];
UNSUPPORTED("dsfdevf6xy6buo0sydh3h3fis"); //     /* leftmost right edge */
UNSUPPORTED("8rdxlzisdq5iw8b07usm1toc9"); //     imaxx =
UNSUPPORTED("a8uyhcvpgmwrihxaaa5u77i69"); // 	r->boundary[2] < s->boundary[2] ? r->boundary[2] : s->boundary[2];
UNSUPPORTED("cr403g6ud2h0cyys19fti84tb"); //     /* downmost top edge */
UNSUPPORTED("cqszcttk6vqvj0hezy1t1bsig"); //     imaxy =
UNSUPPORTED("41qdog59oicvy8ku3n9vbzhj6"); // 	r->boundary[3] < s->boundary[3] ? r->boundary[3] : s->boundary[3];
UNSUPPORTED("cxtiz800rb16yy2u6burhy6mi"); //     return (imaxx - iminx) * (imaxy - iminy);
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 2g71cq6f8w5jbmbnn2x9y5qfq
// static int lblenclosing(object_t * objp, object_t * objp1) 
public static Object lblenclosing(Object... arg) {
UNSUPPORTED("96fk2h2cameoldx630f8490ei"); // static int lblenclosing(object_t * objp, object_t * objp1)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("2uf1ispemhfeg8c7qhy0fbq2j"); //   xlabel_t * xlp = objp->lbl;;
UNSUPPORTED("txl92fx6l8dzi4yeuegwqirj"); //   assert(objp1->sz.x == 0 && objp1->sz.y == 0);
UNSUPPORTED("ek6g4dsfb8puipbh006mizket"); //   if(! xlp) return 0;
UNSUPPORTED("exdts7f2bpam5122kabq2b86c"); //   return objp1->pos.x > xlp->pos.x &&
UNSUPPORTED("99uxf5dqw5nzdymlzfj764uol"); // 	 objp1->pos.x < (xlp->pos.x + xlp->sz.x) &&
UNSUPPORTED("epx7s3oiw75fuioasz208w1k1"); // 	 objp1->pos.y > xlp->pos.y &&
UNSUPPORTED("29g3tye8vebllnv9b91xyntzi"); // 	 objp1->pos.y < (xlp->pos.y + xlp->sz.y);
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 dq1wkb4oxshdggv6cwtgas6m
// static void objp2rect(object_t * op, Rect_t * r) 
public static Object objp2rect(Object... arg) {
UNSUPPORTED("bmdr5joxjahq30nkb15r6rf41"); // static void objp2rect(object_t * op, Rect_t * r)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("cdtyz1w6cga7n2jo2fbh8c6ro"); //     r->boundary[0] = op->pos.x;
UNSUPPORTED("9ir52jgzphc4cgyevo2o2ltjs"); //     r->boundary[1] = op->pos.y;
UNSUPPORTED("cz4cc7haeit4u59so96vv80ch"); //     r->boundary[2] = op->pos.x + op->sz.x;
UNSUPPORTED("3m857h9kn35205vsumkenc0dx"); //     r->boundary[3] = op->pos.y + op->sz.y;
UNSUPPORTED("b9185t6i77ez1ac587ul8ndnc"); //     return;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 71b5ttp3xs7lo9fqgb7ypyqgx
// static void objplp2rect(object_t * objp, Rect_t * r) 
public static Object objplp2rect(Object... arg) {
UNSUPPORTED("5giyzyeu3hmuyo2r06ushsohy"); // static void objplp2rect(object_t * objp, Rect_t * r)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("3wparjbgs7cft1xsjcztm8bdh"); //     xlabel_t *lp = objp->lbl;
UNSUPPORTED("5abhryoldlbjfzt4lh63gmcb4"); //     r->boundary[0] = lp->pos.x;
UNSUPPORTED("acpv39vcusl8yzf591aja97a0"); //     r->boundary[1] = lp->pos.y;
UNSUPPORTED("flr92u77dscu4d286xzfwhzs"); //     r->boundary[2] = lp->pos.x + lp->sz.x;
UNSUPPORTED("beq6fj10iaic6pf2z8xgb1atm"); //     r->boundary[3] = lp->pos.y + lp->sz.y;
UNSUPPORTED("b9185t6i77ez1ac587ul8ndnc"); //     return;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 ksqjbiie0e6vvaeawdxriie5
// static Rect_t objplpmks(XLabels_t * xlp, object_t * objp) 
public static Object objplpmks(Object... arg) {
UNSUPPORTED("56xi0kf7c3v2wjn9pgxjfd6h"); // static Rect_t objplpmks(XLabels_t * xlp, object_t * objp)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("1xpsng8cc6f4327hr9iybol18"); //     Rect_t rect;
UNSUPPORTED("2bghyit203pd6xw2ihhenzyn8"); //     pointf p;
UNSUPPORTED("44i0d8rb96ptawj2nb9zhyuzq"); //     p.x = p.y = 0.0;
UNSUPPORTED("3dwj4u821y9ogiqj7n51lyoag"); //     if (objp->lbl)
UNSUPPORTED("43e7r8tcv1i4842l88wzlv8oh"); // 	p = objp->lbl->sz;
UNSUPPORTED("5vkhq86nkkgbben2zw7acts5t"); //     rect.boundary[0] = (int) floor(objp->pos.x - p.x);
UNSUPPORTED("3smh87oiqzvpexhjkfsvfqk9x"); //     rect.boundary[1] = (int) floor(objp->pos.y - p.y);
UNSUPPORTED("2qxkma0x5w0j667gciafl1erp"); //     rect.boundary[2] = (int) ceil(objp->pos.x + objp->sz.x + p.x);
UNSUPPORTED("6jltyhrpm228xlstvy1cij4b"); //     assert(rect.boundary[2] < INT_MAX);
UNSUPPORTED("aczubaaqymb9ns1q4t70v16a2"); //     rect.boundary[3] = (int) ceil(objp->pos.y + objp->sz.y + p.y);
UNSUPPORTED("560x8steudix953y8g7kyqgph"); //     assert(rect.boundary[3] < INT_MAX);
UNSUPPORTED("5r5gm69aqx2rcthvo0oaisz5n"); //     return rect;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 calnhom3s9dqvvi6crrz3h2wp
// static int getintrsxi(XLabels_t * xlp, object_t * op, object_t * cp) 
public static Object getintrsxi(Object... arg) {
UNSUPPORTED("a9fedvxwftar39hm6zje929tj"); // static int getintrsxi(XLabels_t * xlp, object_t * op, object_t * cp)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("451bp6msra12odk32g38u2p4l"); //     int i = -1;
UNSUPPORTED("6ve3kvakrupo08cfuexjzim3j"); //     xlabel_t *lp = op->lbl, *clp = cp->lbl;
UNSUPPORTED("bot9xncc749y7iruelw2v96mm"); //     assert(lp != clp);
UNSUPPORTED("95np7ge1zv1ws57dp9wu3twm8"); //     if (lp->set == 0 || clp->set == 0)
UNSUPPORTED("11drvggon8u61uz4iw75insly"); // 	return i;
UNSUPPORTED("bofpvwtmumoe1ckgnlgbwg8bt"); //     if ((op->pos.x == 0.0 && op->pos.y == 0.0) ||
UNSUPPORTED("f039op8rn0jopi9r8kora4cwz"); // 	(cp->pos.x == 0.0 && cp->pos.y == 0.0))
UNSUPPORTED("11drvggon8u61uz4iw75insly"); // 	return i;
UNSUPPORTED("5t4dji6xy0hdyx5wguao13hy5"); //     if (cp->pos.y < op->pos.y)
UNSUPPORTED("kx0a7gocqji2ms0neepjemp0"); // 	if (cp->pos.x < op->pos.x)
UNSUPPORTED("al11nyatzn20y82ligyxw6doz"); // 	    i = 0;
UNSUPPORTED("6u28hrhgdf9tpy6v85nmoma8q"); // 	else if (cp->pos.x > op->pos.x)
UNSUPPORTED("3nbwdw3wfkpmnrf8loezvflkx"); // 	    i = 2;
UNSUPPORTED("9352ql3e58qs4fzapgjfrms2s"); // 	else
UNSUPPORTED("akdfo982ws6tlct2c4wlm7hdb"); // 	    i = 1;
UNSUPPORTED("6h2iz13c1pog9oqz0a4f1sqth"); //     else if (cp->pos.y > op->pos.y)
UNSUPPORTED("kx0a7gocqji2ms0neepjemp0"); // 	if (cp->pos.x < op->pos.x)
UNSUPPORTED("2rdl000508m132a9u1h076lba"); // 	    i = 6;
UNSUPPORTED("6u28hrhgdf9tpy6v85nmoma8q"); // 	else if (cp->pos.x > op->pos.x)
UNSUPPORTED("7p6vu0p80gdkcsj4l5hz59dqb"); // 	    i = 8;
UNSUPPORTED("9352ql3e58qs4fzapgjfrms2s"); // 	else
UNSUPPORTED("69apu46xpi0gdi4dt1tir6dbh"); // 	    i = 7;
UNSUPPORTED("73lwftxejfwwrm0v22inmutya"); //     else if (cp->pos.x < op->pos.x)
UNSUPPORTED("9t0t38axcdz9uuxxaxd4e5oi2"); // 	i = 3;
UNSUPPORTED("an605gtk4m1ql9srrrj5k6dah"); //     else if (cp->pos.x > op->pos.x)
UNSUPPORTED("cmp9l0lizmu0ars1jf1oxdms"); // 	i = 5;
UNSUPPORTED("ahwo5hst5k1gyq20ve63ahe81"); //     return i;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 52awwxu810dg9a2pjq45aomam
// static double recordointrsx(XLabels_t * xlp, object_t * op, object_t * cp, Rect_t * rp, 	      double a, object_t * intrsx[9]) 
public static Object recordointrsx(Object... arg) {
UNSUPPORTED("lt6cippjix5bbvyhkcpl8g7g"); // static double
UNSUPPORTED("2zz9cixco1u51p503mmbdrgwj"); // recordointrsx(XLabels_t * xlp, object_t * op, object_t * cp, Rect_t * rp,
UNSUPPORTED("apwjxkvmqelrsmtxwca7febp5"); // 	      double a, object_t * intrsx[9])
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("ejj0lh0dxc3weinkmoqplvk87"); //     int i = getintrsxi(xlp, op, cp);
UNSUPPORTED("7jqpiltkvdvvkjldnxqmz4nfw"); //     if (i < 0)
UNSUPPORTED("cmp9l0lizmu0ars1jf1oxdms"); // 	i = 5;
UNSUPPORTED("b3zyhtz43kkfxl6c8kovnaukv"); //     if (intrsx[i] != (void *)0) {
UNSUPPORTED("908eps96desp6goewhn8nkz4v"); // 	double sa, maxa = 0.0;
UNSUPPORTED("cz5yjl642c9a3c7quub0ndp2a"); // 	Rect_t srect;
UNSUPPORTED("aq0f27u636o0qqw392noohjgj"); // 	/* keep maximally overlapping object */
UNSUPPORTED("5vocmgb870od0q18046qxkydh"); // 	objp2rect(intrsx[i], &srect);
UNSUPPORTED("3by02iwc6g6vz00qca2gs8af1"); // 	sa = aabbaabb(rp, &srect);
UNSUPPORTED("77dloi6nsmguqzpi413an26qc"); // 	if (sa > a)
UNSUPPORTED("8e6d6m12amff6diyc58bdpzap"); // 	    maxa = sa;
UNSUPPORTED("2d4heu1iudrpn42muf8z4aedr"); // 	/*keep maximally overlapping label */
UNSUPPORTED("5g3p1wh0h43afgmy1ttrgr1jv"); // 	if (intrsx[i]->lbl) {
UNSUPPORTED("e5ldv4apogj6g1ixv62v7fqn7"); // 	    objplp2rect(intrsx[i], &srect);
UNSUPPORTED("6h73h574xwo051r2xjepln3kk"); // 	    sa = aabbaabb(rp, &srect);
UNSUPPORTED("cl94uq2flao8cddtvg02oliwb"); // 	    if (sa > a)
UNSUPPORTED("d9hnc5ox6fsga1e2336gg1fwv"); // 		maxa = sa > maxa ? sa : maxa;
UNSUPPORTED("flupwh3kosf3fkhkxllllt1"); // 	}
UNSUPPORTED("6nmie1l1f5g573kzykn3266zd"); // 	if (maxa > 0.0)
UNSUPPORTED("dm9264t4efl70h617d1apqrlj"); // 	    return maxa;
UNSUPPORTED("3vems3bwps1fshis117u06l2l"); // 	/*replace overlapping label/object pair */
UNSUPPORTED("c3ewj48u0ngzq2xd8g3238ays"); // 	intrsx[i] = cp;
UNSUPPORTED("efte22brajv8hm98pgq1oyjc5"); // 	return a;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("2u8wtbwfirvx570l7nhbkqwmn"); //     intrsx[i] = cp;
UNSUPPORTED("3gfohtnqgemf2e1akg4je944a"); //     return a;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 2umrncgkunxoyeuc8i9hd5pwa
// static double recordlintrsx(XLabels_t * xlp, object_t * op, object_t * cp, Rect_t * rp, 	      double a, object_t * intrsx[9]) 
public static Object recordlintrsx(Object... arg) {
UNSUPPORTED("lt6cippjix5bbvyhkcpl8g7g"); // static double
UNSUPPORTED("a36vanbvru4xq84pujn0rdpr5"); // recordlintrsx(XLabels_t * xlp, object_t * op, object_t * cp, Rect_t * rp,
UNSUPPORTED("apwjxkvmqelrsmtxwca7febp5"); // 	      double a, object_t * intrsx[9])
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("ejj0lh0dxc3weinkmoqplvk87"); //     int i = getintrsxi(xlp, op, cp);
UNSUPPORTED("7jqpiltkvdvvkjldnxqmz4nfw"); //     if (i < 0)
UNSUPPORTED("cmp9l0lizmu0ars1jf1oxdms"); // 	i = 5;
UNSUPPORTED("b3zyhtz43kkfxl6c8kovnaukv"); //     if (intrsx[i] != (void *)0) {
UNSUPPORTED("908eps96desp6goewhn8nkz4v"); // 	double sa, maxa = 0.0;
UNSUPPORTED("cz5yjl642c9a3c7quub0ndp2a"); // 	Rect_t srect;
UNSUPPORTED("aq0f27u636o0qqw392noohjgj"); // 	/* keep maximally overlapping object */
UNSUPPORTED("5vocmgb870od0q18046qxkydh"); // 	objp2rect(intrsx[i], &srect);
UNSUPPORTED("3by02iwc6g6vz00qca2gs8af1"); // 	sa = aabbaabb(rp, &srect);
UNSUPPORTED("77dloi6nsmguqzpi413an26qc"); // 	if (sa > a)
UNSUPPORTED("8e6d6m12amff6diyc58bdpzap"); // 	    maxa = sa;
UNSUPPORTED("2d4heu1iudrpn42muf8z4aedr"); // 	/*keep maximally overlapping label */
UNSUPPORTED("5g3p1wh0h43afgmy1ttrgr1jv"); // 	if (intrsx[i]->lbl) {
UNSUPPORTED("e5ldv4apogj6g1ixv62v7fqn7"); // 	    objplp2rect(intrsx[i], &srect);
UNSUPPORTED("6h73h574xwo051r2xjepln3kk"); // 	    sa = aabbaabb(rp, &srect);
UNSUPPORTED("cl94uq2flao8cddtvg02oliwb"); // 	    if (sa > a)
UNSUPPORTED("d9hnc5ox6fsga1e2336gg1fwv"); // 		maxa = sa > maxa ? sa : maxa;
UNSUPPORTED("flupwh3kosf3fkhkxllllt1"); // 	}
UNSUPPORTED("6nmie1l1f5g573kzykn3266zd"); // 	if (maxa > 0.0)
UNSUPPORTED("dm9264t4efl70h617d1apqrlj"); // 	    return maxa;
UNSUPPORTED("3vems3bwps1fshis117u06l2l"); // 	/*replace overlapping label/object pair */
UNSUPPORTED("c3ewj48u0ngzq2xd8g3238ays"); // 	intrsx[i] = cp;
UNSUPPORTED("efte22brajv8hm98pgq1oyjc5"); // 	return a;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("2u8wtbwfirvx570l7nhbkqwmn"); //     intrsx[i] = cp;
UNSUPPORTED("3gfohtnqgemf2e1akg4je944a"); //     return a;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 2td62i5hus8obwt8j1lo3ddj9
// static BestPos_t xlintersections(XLabels_t * xlp, object_t * objp, object_t * intrsx[9]) 
public static Object xlintersections(Object... arg) {
UNSUPPORTED("5d1nc0otrpz1jjsig9p42wcdx"); // static BestPos_t
UNSUPPORTED("6wd33niscsg9gaphvjj2k27mk"); // xlintersections(XLabels_t * xlp, object_t * objp, object_t * intrsx[9])
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("b17di9c7wgtqm51bvsyxz6e2f"); //     int i;
UNSUPPORTED("3zfiovc9yy1ux6pn9mcga1mhx"); //     LeafList_t *ilp, *llp;
UNSUPPORTED("a1j5r089evbgqbrk12ebcposk"); //     Rect_t rect, srect;
UNSUPPORTED("ac14qcqjljksbh1ulqbhsnrnb"); //     BestPos_t bp;
UNSUPPORTED("cep99zzwrn6h0kw9g90d0bcx5"); //     assert(objp->lbl);
UNSUPPORTED("at98kl98nqfoglwklw8bmf8dy"); //     bp.n = 0;
UNSUPPORTED("6umte8r5yaoo1st9aa3ak69vv"); //     bp.area = 0.0;
UNSUPPORTED("6lbd8rbktjb11npai18mqgehg"); //     bp.pos = objp->lbl->pos;
UNSUPPORTED("bu059qij9p4jrq3c2fc3dv1tc"); //     for(i=0; i<xlp->n_objs; i++) {
UNSUPPORTED("2ju28cg7zhx8a22r2nngjed1z"); //       if(objp == &xlp->objs[i]) continue;
UNSUPPORTED("8y5ea7egphfppbq3tbxnqvszd"); //       if(xlp->objs[i].sz.x > 0 && xlp->objs[i].sz.y > 0) continue;
UNSUPPORTED("8kr7yfnz75qb1mcurk9ikvqm4"); //       if(lblenclosing(objp, &xlp->objs[i]) ) {
UNSUPPORTED("4szbt8bacnec4eh6741w9202k"); // 	bp.n++;
UNSUPPORTED("dquo3qofk56ds5xl95lhvcthf"); //       }
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("3kxhpoylut0o1vn46d51xaxmm"); //     objplp2rect(objp, &rect);
UNSUPPORTED("2oyraxz5ikxma3gbfbygvqyfb"); //     llp = RTreeSearch(xlp->spdx, xlp->spdx->root, &rect);
UNSUPPORTED("5gmvhcq1f7m3vaw99uu5u2lhh"); //     if (!llp)
UNSUPPORTED("6t20fkj318tjhdok8hlpbsnf7"); // 	return bp;
UNSUPPORTED("cu0fy461wercnkus2c5pix4y9"); //     for (ilp = llp; ilp; ilp = ilp->next) {
UNSUPPORTED("694r1mgceoxxp4ktbci1h2qnm"); // 	double a, ra;
UNSUPPORTED("6sqdh7rdwpg33jt0ecjx3yobj"); // 	object_t *cp = ilp->leaf->data;
UNSUPPORTED("7wl0z6xy4danjs21muyt94sm7"); // 	if (cp == objp)
UNSUPPORTED("6hqli9m8yickz1ox1qfgtdbnd"); // 	    continue;
UNSUPPORTED("91gncffnouukjk2940jfpcll4"); // 	/*label-object intersect */
UNSUPPORTED("8gzbd1z9dm5uszv31wx6una1n"); // 	objp2rect(cp, &srect);
UNSUPPORTED("c5t1kwupnkevwfpx3deb42y52"); // 	a = aabbaabb(&rect, &srect);
UNSUPPORTED("9zmfoo91yy2c8v5o1x9tul9a5"); // 	if (a > 0.0) {
UNSUPPORTED("di2i1k0ht9d4tbn1d0os7lj44"); // 	  ra = recordointrsx(xlp, objp, cp, &rect, a, intrsx);
UNSUPPORTED("20fp32yan59vu7bbp6jc1t8fn"); // 	  bp.n++;
UNSUPPORTED("asfx7fyb1rvar23xmjcttxkyc"); // 	  bp.area += ra;
UNSUPPORTED("flupwh3kosf3fkhkxllllt1"); // 	}
UNSUPPORTED("6pabj7ne9s1dinxh7rgynt84r"); // 	/*label-label intersect */
UNSUPPORTED("6azbae5tbds7g6ytolv14300v"); // 	if (!cp->lbl || !cp->lbl->set)
UNSUPPORTED("6hqli9m8yickz1ox1qfgtdbnd"); // 	    continue;
UNSUPPORTED("4jw7tfl9ltqgflydxukej7r0d"); // 	objplp2rect(cp, &srect);
UNSUPPORTED("c5t1kwupnkevwfpx3deb42y52"); // 	a = aabbaabb(&rect, &srect);
UNSUPPORTED("9zmfoo91yy2c8v5o1x9tul9a5"); // 	if (a > 0.0) {
UNSUPPORTED("db5ir72mk4a23hg0pqyapmdav"); // 	  ra = recordlintrsx(xlp, objp, cp, &rect, a, intrsx);
UNSUPPORTED("20fp32yan59vu7bbp6jc1t8fn"); // 	  bp.n++;
UNSUPPORTED("asfx7fyb1rvar23xmjcttxkyc"); // 	  bp.area += ra;
UNSUPPORTED("flupwh3kosf3fkhkxllllt1"); // 	}
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("6q4puajbcusq4jhaq2i60nlt4"); //     RTreeLeafListFree(llp);
UNSUPPORTED("bgo7070e5cs998w6zp1ma85ad"); //     return bp;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 8rxvucqsqnqej6h8p1osfnk4b
// static BestPos_t xladjust(XLabels_t * xlp, object_t * objp) 
public static Object xladjust(Object... arg) {
UNSUPPORTED("855u8yvlwgwm8xrgmk8yd4q2g"); // static BestPos_t xladjust(XLabels_t * xlp, object_t * objp)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("3wparjbgs7cft1xsjcztm8bdh"); //     xlabel_t *lp = objp->lbl;
UNSUPPORTED("3z9wizs5r8uuyz9r6zxqmltyr"); //     double xincr = ((2 * lp->sz.x) + objp->sz.x) / 8;
UNSUPPORTED("6y5jbcs5zcnghcye723x4gerv"); //     double yincr = ((2 * lp->sz.y) + objp->sz.y) / 2;
UNSUPPORTED("75ucply06uar4cxvlazotnq23"); //     object_t *intrsx[9];
UNSUPPORTED("9akjtu5ebkpokhkmmtkmz7alu"); //     BestPos_t bp, nbp;
UNSUPPORTED("cep99zzwrn6h0kw9g90d0bcx5"); //     assert(objp->lbl);
UNSUPPORTED("8imr23u6gekt0djjf1kronrfn"); //     memset(intrsx, 0, sizeof(intrsx));
UNSUPPORTED("1yhd7hlhm8avh8zzfa6szjhz"); //     /*x left */
UNSUPPORTED("9j4u90wq1z4maw7hj3ecfdm76"); //     lp->pos.x = objp->pos.x - lp->sz.x;
UNSUPPORTED("dximv1vws8eaor4idmmxl4cxm"); //     /*top */
UNSUPPORTED("2fqhd5bouvdzxkjo7cb26f1be"); //     lp->pos.y = objp->pos.y + objp->sz.y;
UNSUPPORTED("4ol5wxgvom71bm5d6x8u1uhce"); //     bp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("b2di2eiikxmj7aprwrglzmouu"); //     if (bp.n == 0)
UNSUPPORTED("6t20fkj318tjhdok8hlpbsnf7"); // 	return bp;
UNSUPPORTED("aagnln5mk16fd69wnvh7p5m33"); //     /*mid */
UNSUPPORTED("b7imuebo95ow7fl42ukl08csq"); //     lp->pos.y = objp->pos.y;
UNSUPPORTED("4a8niot6lun3zef1tls6aomot"); //     nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5d0zdvxl3sgzkryeuli9o53y8"); //     if (nbp.n == 0)
UNSUPPORTED("6a6aos5zy43mcgqak0sb6pm5f"); // 	return nbp;
UNSUPPORTED("anqn2ghhjsx21704j9hnkxqle"); //     if (nbp.area < bp.area)
UNSUPPORTED("ct5bwjy62uv01c11htvtjj68p"); // 	bp = nbp;
UNSUPPORTED("d0vrsmmihdqn5mrg1ukoz4opr"); //     /*bottom */
UNSUPPORTED("f5b4ggww4fzy0j1ustukdd023"); //     lp->pos.y = objp->pos.y - lp->sz.y;
UNSUPPORTED("4a8niot6lun3zef1tls6aomot"); //     nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5d0zdvxl3sgzkryeuli9o53y8"); //     if (nbp.n == 0)
UNSUPPORTED("6a6aos5zy43mcgqak0sb6pm5f"); // 	return nbp;
UNSUPPORTED("anqn2ghhjsx21704j9hnkxqle"); //     if (nbp.area < bp.area)
UNSUPPORTED("ct5bwjy62uv01c11htvtjj68p"); // 	bp = nbp;
UNSUPPORTED("7fnjcyugtimcpcfm4309c9tdm"); //     /*x mid */
UNSUPPORTED("321pfgsh01nbsjro6xmf2ayfz"); //     lp->pos.x = objp->pos.x;
UNSUPPORTED("dximv1vws8eaor4idmmxl4cxm"); //     /*top */
UNSUPPORTED("2fqhd5bouvdzxkjo7cb26f1be"); //     lp->pos.y = objp->pos.y + objp->sz.y;
UNSUPPORTED("4a8niot6lun3zef1tls6aomot"); //     nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5d0zdvxl3sgzkryeuli9o53y8"); //     if (nbp.n == 0)
UNSUPPORTED("6a6aos5zy43mcgqak0sb6pm5f"); // 	return nbp;
UNSUPPORTED("anqn2ghhjsx21704j9hnkxqle"); //     if (nbp.area < bp.area)
UNSUPPORTED("ct5bwjy62uv01c11htvtjj68p"); // 	bp = nbp;
UNSUPPORTED("d0vrsmmihdqn5mrg1ukoz4opr"); //     /*bottom */
UNSUPPORTED("f5b4ggww4fzy0j1ustukdd023"); //     lp->pos.y = objp->pos.y - lp->sz.y;
UNSUPPORTED("4a8niot6lun3zef1tls6aomot"); //     nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5d0zdvxl3sgzkryeuli9o53y8"); //     if (nbp.n == 0)
UNSUPPORTED("6a6aos5zy43mcgqak0sb6pm5f"); // 	return nbp;
UNSUPPORTED("anqn2ghhjsx21704j9hnkxqle"); //     if (nbp.area < bp.area)
UNSUPPORTED("ct5bwjy62uv01c11htvtjj68p"); // 	bp = nbp;
UNSUPPORTED("630ofptck59xowlm1hcwiue59"); //     /*x right */
UNSUPPORTED("3zrvv0dmz98537x06egk4mwsj"); //     lp->pos.x = objp->pos.x + objp->sz.x;
UNSUPPORTED("dximv1vws8eaor4idmmxl4cxm"); //     /*top */
UNSUPPORTED("2fqhd5bouvdzxkjo7cb26f1be"); //     lp->pos.y = objp->pos.y + objp->sz.y;
UNSUPPORTED("4a8niot6lun3zef1tls6aomot"); //     nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5d0zdvxl3sgzkryeuli9o53y8"); //     if (nbp.n == 0)
UNSUPPORTED("6a6aos5zy43mcgqak0sb6pm5f"); // 	return nbp;
UNSUPPORTED("anqn2ghhjsx21704j9hnkxqle"); //     if (nbp.area < bp.area)
UNSUPPORTED("ct5bwjy62uv01c11htvtjj68p"); // 	bp = nbp;
UNSUPPORTED("aagnln5mk16fd69wnvh7p5m33"); //     /*mid */
UNSUPPORTED("b7imuebo95ow7fl42ukl08csq"); //     lp->pos.y = objp->pos.y;
UNSUPPORTED("4a8niot6lun3zef1tls6aomot"); //     nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5d0zdvxl3sgzkryeuli9o53y8"); //     if (nbp.n == 0)
UNSUPPORTED("6a6aos5zy43mcgqak0sb6pm5f"); // 	return nbp;
UNSUPPORTED("anqn2ghhjsx21704j9hnkxqle"); //     if (nbp.area < bp.area)
UNSUPPORTED("ct5bwjy62uv01c11htvtjj68p"); // 	bp = nbp;
UNSUPPORTED("d0vrsmmihdqn5mrg1ukoz4opr"); //     /*bottom */
UNSUPPORTED("f5b4ggww4fzy0j1ustukdd023"); //     lp->pos.y = objp->pos.y - lp->sz.y;
UNSUPPORTED("4a8niot6lun3zef1tls6aomot"); //     nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5d0zdvxl3sgzkryeuli9o53y8"); //     if (nbp.n == 0)
UNSUPPORTED("6a6aos5zy43mcgqak0sb6pm5f"); // 	return nbp;
UNSUPPORTED("anqn2ghhjsx21704j9hnkxqle"); //     if (nbp.area < bp.area)
UNSUPPORTED("ct5bwjy62uv01c11htvtjj68p"); // 	bp = nbp;
UNSUPPORTED("6eft7mmbcin2x9bhx6gvtc33b"); //     /*sliding from top left */
UNSUPPORTED("2lmnvn101cpkt9b1cwipe71gz"); //     if (intrsx[6] || intrsx[7] || intrsx[8] || intrsx[3] || intrsx[0]) {	/* have to move */
UNSUPPORTED("c5acs4cl77hgu5j6nmhk090uz"); // 	if (!intrsx[7] && !intrsx[8]) {	/* some room right? */
UNSUPPORTED("ez8sbh237xdqdjeewev2ys74y"); // 	    /* slide along upper edge */
UNSUPPORTED("ajgw2jggmwmofm77lgbx5eo2n"); // 	    for (lp->pos.x = objp->pos.x - lp->sz.x,
UNSUPPORTED("nwfhss2g67z5exjkorj0brd"); // 		 lp->pos.y = objp->pos.y + objp->sz.y;
UNSUPPORTED("eav75dwa3f3ieedr9mnov3a6u"); // 		 lp->pos.x <= (objp->pos.x + objp->sz.x);
UNSUPPORTED("38u334kkfej5n3r31uv1afw9q"); // 		 lp->pos.x += xincr) {
UNSUPPORTED("8pbum2o0fs86ceaiuxv4efbb6"); // 		nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5xx7o143ftoj0rhyhg1hqgioa"); // 		if (nbp.n == 0)
UNSUPPORTED("eqanxe9w90oki7yqvwyzpfcw1"); // 		    return nbp;
UNSUPPORTED("8yd6g3a3f0g09gmu5f67vah0x"); // 		if (nbp.area < bp.area)
UNSUPPORTED("d6ac36j6lh6qspxwnn3vi0uc3"); // 		    bp = nbp;
UNSUPPORTED("6t98dcecgbvbvtpycwiq2ynnj"); // 	    }
UNSUPPORTED("flupwh3kosf3fkhkxllllt1"); // 	}
UNSUPPORTED("4w0qgfnt6kpuhb381pmra3ln4"); // 	if (!intrsx[3] && !intrsx[0]) {	/* some room down? */
UNSUPPORTED("6st33ex0udr4mk4sa9vd119uz"); // 	    /* slide down left edge */
UNSUPPORTED("ajgw2jggmwmofm77lgbx5eo2n"); // 	    for (lp->pos.x = objp->pos.x - lp->sz.x,
UNSUPPORTED("nwfhss2g67z5exjkorj0brd"); // 		 lp->pos.y = objp->pos.y + objp->sz.y;
UNSUPPORTED("eolwmrajeldp9gf9ug6ue0gx2"); // 		 lp->pos.y >= (objp->pos.y - lp->sz.y);
UNSUPPORTED("bz3822dbe0xnwj4nm7pf39kae"); // 		 lp->pos.y -= yincr) {
UNSUPPORTED("8pbum2o0fs86ceaiuxv4efbb6"); // 		nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5xx7o143ftoj0rhyhg1hqgioa"); // 		if (nbp.n == 0)
UNSUPPORTED("eqanxe9w90oki7yqvwyzpfcw1"); // 		    return nbp;
UNSUPPORTED("8yd6g3a3f0g09gmu5f67vah0x"); // 		if (nbp.area < bp.area)
UNSUPPORTED("d6ac36j6lh6qspxwnn3vi0uc3"); // 		    bp = nbp;
UNSUPPORTED("6t98dcecgbvbvtpycwiq2ynnj"); // 	    }
UNSUPPORTED("flupwh3kosf3fkhkxllllt1"); // 	}
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("8nu4s12gyh52h2ot9r2mlueuv"); //     /*sliding from bottom right */
UNSUPPORTED("3zrvv0dmz98537x06egk4mwsj"); //     lp->pos.x = objp->pos.x + objp->sz.x;
UNSUPPORTED("f5b4ggww4fzy0j1ustukdd023"); //     lp->pos.y = objp->pos.y - lp->sz.y;
UNSUPPORTED("9bzyoo2lc0pw2w76mz7eeduvc"); //     if (intrsx[2] || intrsx[1] || intrsx[0] || intrsx[5] || intrsx[8]) {	/* have to move */
UNSUPPORTED("dq7ul34gznvszkqhgqlz4fihm"); // 	if (!intrsx[1] && !intrsx[0]) {	/* some room left? */
UNSUPPORTED("ahn6dk8lj2by2umnd8pceb83d"); // 	    /* slide along lower edge */
UNSUPPORTED("7natp0873pfsvymhhhvki1sev"); // 	    for (lp->pos.x = objp->pos.x + objp->sz.x,
UNSUPPORTED("56ycmo0ljb7e86mnezdx3regh"); // 		 lp->pos.y = objp->pos.y - lp->sz.y;
UNSUPPORTED("3wro576dh2vj9wpmfxx4rldbm"); // 		 lp->pos.x >= (objp->pos.x - lp->sz.x);
UNSUPPORTED("bvw5pjd7v4j796l8hhh1zrln6"); // 		 lp->pos.x -= xincr) {
UNSUPPORTED("8pbum2o0fs86ceaiuxv4efbb6"); // 		nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5xx7o143ftoj0rhyhg1hqgioa"); // 		if (nbp.n == 0)
UNSUPPORTED("eqanxe9w90oki7yqvwyzpfcw1"); // 		    return nbp;
UNSUPPORTED("8yd6g3a3f0g09gmu5f67vah0x"); // 		if (nbp.area < bp.area)
UNSUPPORTED("d6ac36j6lh6qspxwnn3vi0uc3"); // 		    bp = nbp;
UNSUPPORTED("6t98dcecgbvbvtpycwiq2ynnj"); // 	    }
UNSUPPORTED("flupwh3kosf3fkhkxllllt1"); // 	}
UNSUPPORTED("4owpyb9p8esm06ttngj1arl5c"); // 	if (!intrsx[5] && !intrsx[8]) {	/* some room up? */
UNSUPPORTED("4bcpk3ixfwrlr0yzrjv2efigj"); // 	    /* slide up right edge */
UNSUPPORTED("7natp0873pfsvymhhhvki1sev"); // 	    for (lp->pos.x = objp->pos.x + objp->sz.x,
UNSUPPORTED("56ycmo0ljb7e86mnezdx3regh"); // 		 lp->pos.y = objp->pos.y - lp->sz.y;
UNSUPPORTED("9cepfi69gtzy7muk9d27es8oc"); // 		 lp->pos.y <= (objp->pos.y + objp->sz.y);
UNSUPPORTED("az41g895dhl39ckrigxl1c5jl"); // 		 lp->pos.y += yincr) {
UNSUPPORTED("8pbum2o0fs86ceaiuxv4efbb6"); // 		nbp = xlintersections(xlp, objp, intrsx);
UNSUPPORTED("5xx7o143ftoj0rhyhg1hqgioa"); // 		if (nbp.n == 0)
UNSUPPORTED("eqanxe9w90oki7yqvwyzpfcw1"); // 		    return nbp;
UNSUPPORTED("8yd6g3a3f0g09gmu5f67vah0x"); // 		if (nbp.area < bp.area)
UNSUPPORTED("d6ac36j6lh6qspxwnn3vi0uc3"); // 		    bp = nbp;
UNSUPPORTED("6t98dcecgbvbvtpycwiq2ynnj"); // 	    }
UNSUPPORTED("flupwh3kosf3fkhkxllllt1"); // 	}
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("bgo7070e5cs998w6zp1ma85ad"); //     return bp;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 e29g2hwlogx0zchsnvi464c7t
// static int xlhdxload(XLabels_t * xlp) 
public static Object xlhdxload(Object... arg) {
UNSUPPORTED("ttxmlo99ck9eo0jae04cg2v0"); // static int xlhdxload(XLabels_t * xlp)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("b17di9c7wgtqm51bvsyxz6e2f"); //     int i;
UNSUPPORTED("5qghcwlht7sxz3cthtja5f043"); //     int order = xlhorder(xlp);
UNSUPPORTED("eali4r93mgkm937waq6to82sj"); //     for (i = 0; i < xlp->n_objs; i++) {
UNSUPPORTED("aves0wxiz65s447kr8wukl6zr"); // 	HDict_t *hp;
UNSUPPORTED("43j1m17g0mjbn69pbx7ph6omt"); // 	point pi;
UNSUPPORTED("bn6ewrzw1x1whedilfc6kobal"); // 	hp = (HDict_t*)zmalloc(sizeof(HDict_t));
UNSUPPORTED("5wresbe1bm8eff0j10in23a8b"); // 	hp->d.data = &xlp->objs[i];
UNSUPPORTED("7syosspcm4ygedrsu0c1gaqop"); // 	hp->d.rect = objplpmks(xlp, &xlp->objs[i]);
UNSUPPORTED("6mb29odwxakb6cqdulhhed9j5"); // 	/* center of the labeling area */
UNSUPPORTED("83ihi4lf580lzo4gdus20wr2w"); // 	pi.x = hp->d.rect.boundary[0] +
UNSUPPORTED("ao944ocofv44otdeh08kl4u8o"); // 	    (hp->d.rect.boundary[2] - hp->d.rect.boundary[0]) / 2;
UNSUPPORTED("3igtyiyl8cpovcwukpm44iquw"); // 	pi.y = hp->d.rect.boundary[1] +
UNSUPPORTED("3r4kfmd4lw5d0osh14sf4cjwg"); // 	    (hp->d.rect.boundary[3] - hp->d.rect.boundary[1]) / 2;
UNSUPPORTED("42x3x9vgkald7xdpbxyxih2zj"); // 	hp->key = hd_hil_s_from_xy(pi, order);
UNSUPPORTED("4apoyv2n3t2fcv72hom4owvgj"); // 	if (!((*(((Dt_t*)(xlp->hdx))->searchf))((xlp->hdx),(void*)(hp),0000001)))
UNSUPPORTED("aivfd7ajlfz8o8oi68d4u5s5z"); // 	    return -1;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("5oxhd3fvp0gfmrmz12vndnjt"); //     return 0;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 26qpvnyd6tmdut8i2wo4itza3
// static void xlhdxunload(XLabels_t * xlp) 
public static Object xlhdxunload(Object... arg) {
UNSUPPORTED("4bsnj74f63qe288s6be1xmrzw"); // static void xlhdxunload(XLabels_t * xlp)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("9sqtid8yyo2ws8avf33utdebf"); //   int size=dtsize(xlp->hdx), freed=0;
UNSUPPORTED("dm7bmt2fwlkdskmcebdm1ctqj"); //   while(dtsize(xlp->hdx) ) {
UNSUPPORTED("a3jz6ykhoarsdfviidq7beb9z"); //     void*vp=(((Dt_t*)(xlp->hdx))->data->here ? (((Dt_t*)((xlp->hdx)))->disc->link < 0 ? ((Dthold_t*)((((Dt_t*)(xlp->hdx))->data->here)))->obj : (void*)((char*)((((Dt_t*)(xlp->hdx))->data->here)) - ((Dt_t*)((xlp->hdx)))->disc->link) ):(void*)(0));
UNSUPPORTED("2covsywkzvpkysnjf34nmr1uw"); //     assert(vp);
UNSUPPORTED("a9jmr8hmnwcky7f1e1qorwnjv"); //     if(vp) {
UNSUPPORTED("d2vfgb4tj6x8x7cq0kv0qgk23"); //       (*(((Dt_t*)(xlp->hdx))->searchf))((xlp->hdx),(void*)(vp),0010000);
UNSUPPORTED("7f4abg2jsf465jjlnp95d9sk6"); //       free(vp);
UNSUPPORTED("5hklxkrkvjgi37kkm6v9xajwc"); //       freed++;
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("7ijd6pszsxnoopppf6xwo8wdl"); //   }
UNSUPPORTED("bifp41eoqo8l51crrab087z21"); //   assert(size==freed);
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 3wrxwwd3y5ts0ekr32o8vhuvv
// static int xlspdxload(XLabels_t * xlp) 
public static Object xlspdxload(Object... arg) {
UNSUPPORTED("87f4jxirnq7mx28zcremgaezf"); // static int xlspdxload(XLabels_t * xlp)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("eoerd3bf05xvvfj7aisz4slcs"); //     HDict_t *op=0;
UNSUPPORTED("2ub4kt9g1hlj02ucnbi3as0ps"); //     for (op = (*(((Dt_t*)(xlp->hdx))->searchf))((xlp->hdx),(void*)(0),0000200); op; op = (*(((Dt_t*)(xlp->hdx))->searchf))((xlp->hdx),(void*)(op),0000010)) {
UNSUPPORTED("cklsugu3v9hzi5pvl4dqcq7gf"); // 	/*          tree       rectangle    data        node             lvl */
UNSUPPORTED("b49ahflq7xke1g6eoxv0jw2tg"); // 	RTreeInsert(xlp->spdx, &op->d.rect, op->d.data, &xlp->spdx->root, 0);
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("5oxhd3fvp0gfmrmz12vndnjt"); //     return 0;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 6d3fqrllm55toeo3wscwvv4ty
// static int xlinitialize(XLabels_t * xlp) 
public static Object xlinitialize(Object... arg) {
UNSUPPORTED("732719k3woyiirridxkwkzxoo"); // static int xlinitialize(XLabels_t * xlp)
UNSUPPORTED("erg9i1970wdri39osu8hx2a6e"); // {
UNSUPPORTED("4s45njph0l3mj07r60fuv2k3y"); //     int r=0;
UNSUPPORTED("ez5mifho06mx5h3ncausptuzp"); //     if ((r = xlhdxload(xlp)) < 0)
UNSUPPORTED("bt8wt6mqb316pv7egiekltb74"); // 	return r;
UNSUPPORTED("f2rrvhf7kqopq3w2vk3a66gqq"); //     if ((r = xlspdxload(xlp)) < 0)
UNSUPPORTED("bt8wt6mqb316pv7egiekltb74"); // 	return r;
UNSUPPORTED("5stn8d1urg4jlet1hh0it6cnh"); //     xlhdxunload(xlp);
UNSUPPORTED("bevdavatk2tsg3i7wugaqk0ta"); //     return dtclose(xlp->hdx);
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}




//3 brqgbskh3z4ah8infjompibvu
// int placeLabels(object_t * objs, int n_objs, 	    xlabel_t * lbls, int n_lbls, label_params_t * params) 
public static int placeLabels(__ptr__ objs, int n_objs, __ptr__ lbls, int n_lbls, label_params_t params) {
int r, i;
BestPos_t bp;
XLabels_t xlp = xlnew(objs, n_objs, lbls, n_lbls, params);
UNSUPPORTED("dm5w2lmehr2rv6b2yi2v83i3g"); //     if ((r = xlinitialize(xlp)) < 0)
UNSUPPORTED("bt8wt6mqb316pv7egiekltb74"); // 	return r;
UNSUPPORTED("8izrf1sxed8y2dmpz5ju27b6h"); //     /* Place xlabel_t* lp near lp->obj so that the rectangle whose lower-left
UNSUPPORTED("dy7wplw95swrlkv1ne5udmbk4"); //      * corner is lp->pos, and size is lp->sz does not intersect any object
UNSUPPORTED("8x5vdo798lnffr7xy14gs8x50"); //      * in objs (by convention, an object consisting of a single point
UNSUPPORTED("9gxb8rlhafdv5g89oagw3add7"); //      * intersects nothing) nor any other label, if possible. On input,
UNSUPPORTED("4w8t3nbzjsvab8g9jpodkwd8m"); //      * lp->set is 0.
UNSUPPORTED("e715w78m2sgdlih8srgyerdiv"); //      *
UNSUPPORTED("z4vevdpoynmn19xji08qzk3g"); //      * On output, any label with a position should have this stored in
UNSUPPORTED("4v5b9m6g4uktmdpnsll0erj7z"); //      * lp->pos and have lp->set non-zero.
UNSUPPORTED("e715w78m2sgdlih8srgyerdiv"); //      *
UNSUPPORTED("3lkc8tv6lv7r7ufa9evyti04j"); //      * If params->force is true, all labels must be positioned, even if
UNSUPPORTED("4lybka8gtaqneks34nylp952d"); //      * overlaps are necessary.
UNSUPPORTED("e715w78m2sgdlih8srgyerdiv"); //      *
UNSUPPORTED("5frb7jkllwey3jie0brk7sexw"); //      * Return 0 if all labels could be placed without overlap;
UNSUPPORTED("b8t343yuuec8v0l5c25l9lpi9"); //      * non-zero otherwise.
UNSUPPORTED("795vpnc8yojryr8b46aidsu69"); //      */
UNSUPPORTED("dfy198s0balu93ez4di7muow9"); //     r = 0;
UNSUPPORTED("bznihqrwh4167vo2mn4du53da"); //     for (i = 0; i < n_objs; i++) {
UNSUPPORTED("1kray7p45i859cpqe20uu98y6"); // 	if (objs[i].lbl == 0)
UNSUPPORTED("6hqli9m8yickz1ox1qfgtdbnd"); // 	    continue;
UNSUPPORTED("572cl1ylp2iqus4kjdigoqut3"); // 	bp = xladjust(xlp, &objs[i]);
UNSUPPORTED("dr8tnm5vyr6b4kb5le39f33s9"); // 	if (bp.n == 0) {
UNSUPPORTED("1wsz4ptoxskyulgu7czf059sf"); // 	    objs[i].lbl->set = 1;
UNSUPPORTED("crlmrxaiu6t07d3ztas7pwfoi"); // 	} else if(bp.area == 0) {
UNSUPPORTED("djsgfzak14js9ukvgmoqnkm8v"); // 	    objs[i].lbl->pos.x = bp.pos.x;
UNSUPPORTED("5s2aq4djc0l3xyilkowd7ri1r"); // 	    objs[i].lbl->pos.y = bp.pos.y;
UNSUPPORTED("1wsz4ptoxskyulgu7czf059sf"); // 	    objs[i].lbl->set = 1;
UNSUPPORTED("19st2bzrcserz5r5280g8iwb8"); // 	} else if (params->force == 1) {
UNSUPPORTED("djsgfzak14js9ukvgmoqnkm8v"); // 	    objs[i].lbl->pos.x = bp.pos.x;
UNSUPPORTED("5s2aq4djc0l3xyilkowd7ri1r"); // 	    objs[i].lbl->pos.y = bp.pos.y;
UNSUPPORTED("1wsz4ptoxskyulgu7czf059sf"); // 	    objs[i].lbl->set = 1;
UNSUPPORTED("7yhr8hn3r6wohafwxrt85b2j2"); // 	} else {
UNSUPPORTED("cqgdtl138trieiu5el4upwpg0"); // 	    r = 1;
UNSUPPORTED("flupwh3kosf3fkhkxllllt1"); // 	}
UNSUPPORTED("dvgyxsnyeqqnyzq696k3vskib"); //     }
UNSUPPORTED("6oy0ry9luo305no4iuqqxcdjr"); //     xlfree(xlp);
UNSUPPORTED("a2hk6w52njqjx48nq3nnn2e5i"); //     return r;
UNSUPPORTED("c24nfmv9i7o5eoqaymbibp7m7"); // }

throw new UnsupportedOperationException();
}


}
